<?php
/**
 * featured_product Section options
 *
 * @package Theme Palace
 * @subpackage shopall Pro
 * @since shopall Pro 1.0.0
 */
$customizer_title = esc_html__( 'Featured Product','shopall-pro' );
$customizer_description = esc_html__( 'Featured Product Section options.', 'shopall-pro' );
if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design' ) {
	$customizer_title = esc_html__( 'Must Read','shopall-pro' );
	$customizer_description = esc_html__( 'Must Read Section Options.', 'shopall-pro' );
}
// Add featured_product section
$wp_customize->add_section( 'shopall_pro_featured_product_section', array(
	'title'             => $customizer_title,
	'description'       => $customizer_description,
	'panel'             => 'shopall_pro_front_page_panel',
) );

// featured_product content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_section_enable]', array(
	'default'			=> 	$options['featured_product_section_enable'],
	'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[featured_product_section_enable]', array(
	'label'             => $customizer_title.esc_html__( ' Section Enable', 'shopall-pro' ),
	'section'           => 'shopall_pro_featured_product_section',
	'on_off_label' 		=> shopall_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_count]', array(
	'default'          	=> $options['featured_product_count'],
	'sanitize_callback' => 'shopall_pro_sanitize_number_range',
	'validate_callback' => 'shopall_pro_validate_featured_product_count',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[featured_product_count]', array(
	'label'             => esc_html__( 'Number of post', 'shopall-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'shopall-pro' ),
	'section'           => 'shopall_pro_featured_product_section',
	'active_callback'   => 'shopall_pro_is_featured_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design') {

	$wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_btn_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'shopall_pro_theme_options[featured_product_btn_title]', array(
		'label'           	=> esc_html__( 'Button Label', 'shopall-pro' ),
		'section'        	=> 'shopall_pro_featured_product_section',
		'active_callback' 	=> 'shopall_pro_is_featured_product_section_enable',
		'type'				=> 'text',
	) );
}

// featured_product content type control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_content_type]', array(
	'default'          	=> $options['featured_product_content_type'],
	'sanitize_callback' => 'shopall_pro_sanitize_select',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[featured_product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'shopall-pro' ),
	'section'           => 'shopall_pro_featured_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'shopall_pro_is_featured_product_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'shopall-pro' ),
		'post' 		=> esc_html__( 'Post', 'shopall-pro' ),
		'category' 	=> esc_html__( 'Category', 'shopall-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_product_count']; $i++ ) :
	// featured_product pages drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[featured_product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_featured_product_section',
		'choices'			=> shopall_pro_page_choices(),
		'active_callback'	=> 'shopall_pro_is_featured_product_section_content_page_enable',
	) ) );

	// featured_product posts drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_content_post_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[featured_product_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_featured_product_section',
		'choices'			=> shopall_pro_post_choices(),
		'active_callback'	=> 'shopall_pro_is_featured_product_section_content_post_enable',
	) ) );

	if ( ! in_array( $options['home_layout'],  array( 'fourth-design', 'fifth-design' ) ) ) {
		$options['featured_product_btn_title_'.$i] = isset($options['featured_product_btn_title_'.$i]) ? $options['featured_product_btn_title_'.$i] : esc_html__('Start Shopping', 'shopall-pro') ;
		$wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_btn_title_'.$i.']', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> $options['featured_product_btn_title_'.$i],
		) );

		$wp_customize->add_control( 'shopall_pro_theme_options[featured_product_btn_title_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Button Label %d', 'shopall-pro' ), $i ),
			'section'        	=> 'shopall_pro_featured_product_section',
			'active_callback' 	=> 'shopall_pro_is_featured_product_section_enable',
			'type'				=> 'text',
		) );

		// blog btn title setting and control
		$wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_btn_url_'.$i.']', array(
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'shopall_pro_theme_options[featured_product_btn_url_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Button Url %d', 'shopall-pro' ), $i ),
			'section'        	=> 'shopall_pro_featured_product_section',
			'active_callback' 	=> 'shopall_pro_is_featured_product_section_enable',
			'type'				=> 'url',
		) );
	}
	

    $wp_customize->add_setting( 'shopall_pro_theme_options[featured_product_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[featured_product_hr_'. $i .']',
        array(
            'section'           => 'shopall_pro_featured_product_section',
            'active_callback'   => 'shopall_pro_is_featured_product_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'shopall_pro_theme_options[featured_product_content_category]', array(
	'sanitize_callback' => 'shopall_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Shopall_Pro_Dropdown_Taxonomy_Control( $wp_customize,'shopall_pro_theme_options[featured_product_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'shopall-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'shopall-pro' ),
	'section'           => 'shopall_pro_featured_product_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'shopall_pro_is_featured_product_section_content_category_enable'
) ) );