<?php
/**
 * partner Section options
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */
// Add partner Collection section
$wp_customize->add_section( 'shopall_pro_partner_section', array(
    'title'             => esc_html__( 'Partner','shopall-pro' ),
    'description'       => esc_html__( 'Partner Section options.', 'shopall-pro' ),
    'panel'             => 'shopall_pro_front_page_panel',
) );

// partner content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[partner_section_enable]', array(
    'default'           =>  $options['partner_section_enable'],
    'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[partner_section_enable]', array(
    'label'             => esc_html__( 'Partner Section Enable', 'shopall-pro' ),
    'section'           => 'shopall_pro_partner_section',
    'on_off_label'      => shopall_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'shopall_pro_theme_options[partner_count]', array(
    'default'           => $options['partner_count'],
    'sanitize_callback' => 'shopall_pro_sanitize_number_range',
    'validate_callback' => 'shopall_pro_validate_client_count',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[partner_count]', array(
    'label'             => esc_html__( 'Number of partner', 'shopall-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'shopall-pro' ),
    'section'           => 'shopall_pro_partner_section',
    'active_callback'   => 'shopall_pro_is_partner_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'shopall_pro_theme_options[partner_content_type]', array(
    'default'           => $options['partner_content_type'],
    'sanitize_callback' => 'shopall_pro_sanitize_select',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[partner_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'shopall-pro' ),
    'section'           => 'shopall_pro_partner_section',
    'type'              => 'select',
    'active_callback'   => 'shopall_pro_is_partner_section_enable',
    'choices'           => array( 
        'page'          => esc_html__( 'Page', 'shopall-pro' ),
        'post'          => esc_html__( 'Post', 'shopall-pro' ),
        'category'          => esc_html__( 'Category', 'shopall-pro' ),
        'custom'        => esc_html__( 'Custom', 'shopall-pro' ),
    ),
) );

for ($i=1; $i <= $options['partner_count'] ; $i++) :
    // partner pages drop down chooser control and setting
    $wp_customize->add_setting( 'shopall_pro_theme_options[partner_content_page_' . $i . ']', array(
        'sanitize_callback' => 'shopall_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[partner_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Page %d', 'shopall-pro' ), $i ),
        'section'           => 'shopall_pro_partner_section',
        'choices'           => shopall_pro_page_choices(),
        'active_callback'   => 'shopall_pro_is_partner_section_content_page_enable',
    ) ) );

    // partner posts drop down chooser control and setting
    $wp_customize->add_setting( 'shopall_pro_theme_options[partner_content_post_' . $i . ']', array(
        'sanitize_callback' => 'shopall_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[partner_content_post_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Post %d', 'shopall-pro' ), $i ),
        'section'           => 'shopall_pro_partner_section',
        'choices'           => shopall_pro_post_choices(),
        'active_callback'   => 'shopall_pro_is_partner_section_content_post_enable',
    ) ) );

    $wp_customize->add_setting( 'shopall_pro_theme_options[partner_image_' . $i . ']', array(
        'sanitize_callback' => 'shopall_pro_sanitize_image',
    ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'shopall_pro_theme_options[partner_image_' . $i . ']',
            array(
            'label'             => sprintf( esc_html__( 'partner Logo %d', 'shopall-pro' ), $i ),
            'section'           => 'shopall_pro_partner_section',
            'active_callback'   => 'shopall_pro_is_partner_section_content_custom_enable',
    ) ) );

    $wp_customize->add_setting( 'shopall_pro_theme_options[partner_url_' . $i . ']', array(
        'sanitize_callback' => 'esc_url_raw',
    ) );

    $wp_customize->add_control( 'shopall_pro_theme_options[partner_url_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'partner Url %d', 'shopall-pro' ), $i ),
        'section'           => 'shopall_pro_partner_section',
        'active_callback'   => 'shopall_pro_is_partner_section_content_custom_enable',
        'type'              => 'url',
    ) );


    $wp_customize->add_setting( 'shopall_pro_theme_options[partner_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[partner_hr_'. $i .']',
        array(
            'section'           => 'shopall_pro_partner_section',
            'active_callback'   => 'shopall_pro_is_partner_section_enable',
            'type'            => 'hr'
    ) ) );

endfor;

$wp_customize->add_setting(  'shopall_pro_theme_options[partner_content_category]', array(
    'sanitize_callback' => 'shopall_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Shopall_Pro_Dropdown_Taxonomies_Control( $wp_customize,'shopall_pro_theme_options[partner_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'shopall-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'shopall-pro' ),
    'section'           => 'shopall_pro_partner_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'shopall_pro_is_partner_section_content_category_enable'
) ) );



        