<?php
/**
 * Popular Product Section options
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}
// Add Popular Product section
$wp_customize->add_section( 'shopall_pro_popular_product_section', array(
    'title'             => esc_html__( 'Popular Product','shopall-pro' ),
    'description'       => esc_html__( 'Popular Product Section options.', 'shopall-pro' ),
    'panel'             => 'shopall_pro_front_page_panel',
) );

// Popular Product content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[popular_product_section_enable]', array(
    'default'           =>  $options['popular_product_section_enable'],
    'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[popular_product_section_enable]', array(
    'label'             => esc_html__( 'Popular Product Section Enable', 'shopall-pro' ),
    'section'           => 'shopall_pro_popular_product_section',
    'on_off_label'      => shopall_pro_switch_options(),
) ) );  

// popular_product title setting and control
$wp_customize->add_setting( 'shopall_pro_theme_options[popular_product_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_product_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[popular_product_title]', array(
    'label'             => esc_html__( 'Title', 'shopall-pro' ),
    'section'           => 'shopall_pro_popular_product_section',
    'active_callback'   => 'shopall_pro_is_popular_product_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[popular_product_title]', array(
        'selector'            => '#popular-products .wrapper .section-header h2',
        'settings'            => 'shopall_pro_theme_options[popular_product_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'shopall_pro_popular_product_title_partial',
    ) );
}

// popular_product title setting and control
$wp_customize->add_setting( 'shopall_pro_theme_options[popular_product_sub_title]', array(
    'sanitize_callback' => 'wp_kses_post',
    'default'           => $options['popular_product_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[popular_product_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'shopall-pro' ),
    'section'           => 'shopall_pro_popular_product_section',
    'active_callback'   => 'shopall_pro_is_popular_product_section_enable',
    'type'              => 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[popular_product_sub_title]', array(
        'selector'            => '#popular-products .wrapper .section-header p',
        'settings'            => 'shopall_pro_theme_options[popular_product_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'shopall_pro_popular_product_sub_title_partial',
    ) );
}





$wp_customize->add_setting(  'shopall_pro_theme_options[popular_product_tag]', array(
    'sanitize_callback' => 'shopall_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Shopall_Pro_Dropdown_Taxonomies_Control( $wp_customize,'shopall_pro_theme_options[popular_product_tag]', array(
    'label'             => esc_html__( 'Select Product Tags', 'shopall-pro' ),
    'description'       => esc_html__( 'Note: Press CTRL and select multiple tag. popular four posts will be shown from each selected category', 'shopall-pro' ),
    'section'           => 'shopall_pro_popular_product_section',
    'taxonomy'          => 'product_tag',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'shopall_pro_is_popular_product_section_enable',
) ) );
