<?php
/**
 * service Section options
 *
 * @package Theme Palace
 * @subpackage shopall Pro
 * @since shopall Pro 1.0.0
 */

// Add service section
$wp_customize->add_section( 'shopall_pro_service_section', array(
	'title'             => esc_html__( 'Service','shopall-pro' ),
	'description'       => esc_html__( 'Service Section options.', 'shopall-pro' ),
	'panel'             => 'shopall_pro_front_page_panel',
) );

// service content enable control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'shopall-pro' ),
	'section'           => 'shopall_pro_service_section',
	'on_off_label' 		=> shopall_pro_switch_options(),
) ) );

// service content type control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[service_column_layout]', array(
	'default'          	=> $options['service_column_layout'],
	'sanitize_callback' => 'shopall_pro_sanitize_select',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[service_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'shopall-pro' ),
	'section'           => 'shopall_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'shopall_pro_is_service_section_enable',
	'choices'			=> array( 
		'col-3' 		=> esc_html__( '3 Column', 'shopall-pro' ),
		'col-4' 		=> esc_html__( '4 Column', 'shopall-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'shopall_pro_sanitize_number_range',
	'validate_callback' => 'shopall_pro_validate_service_count',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'shopall-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'shopall-pro' ),
	'section'           => 'shopall_pro_service_section',
	'active_callback'   => 'shopall_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// service content type control and setting
$wp_customize->add_setting( 'shopall_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'shopall_pro_sanitize_select',
) );

$wp_customize->add_control( 'shopall_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'shopall-pro' ),
	'section'           => 'shopall_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'shopall_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'shopall-pro' ),
		'post' 		=> esc_html__( 'Post', 'shopall-pro' ),
		'category' 	=> esc_html__( 'Category', 'shopall-pro' ),
	),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :
	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_service_section',
		'choices'			=> shopall_pro_page_choices(),
		'active_callback'	=> 'shopall_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'shopall_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'shopall_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Shopall_Pro_Dropdown_Chooser( $wp_customize, 'shopall_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'shopall-pro' ), $i ),
		'section'           => 'shopall_pro_service_section',
		'choices'			=> shopall_pro_post_choices(),
		'active_callback'	=> 'shopall_pro_is_service_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'shopall_pro_theme_options[service_content_icon_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( new Shopall_Pro_Icon_Picker( $wp_customize, 'shopall_pro_theme_options[service_content_icon_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Icon %d', 'shopall-pro' ), $i ),
        'section'           => 'shopall_pro_service_section',
        'active_callback'   => 'shopall_pro_is_service_section_enable',
    ) ) );

    $wp_customize->add_setting( 'shopall_pro_theme_options[service_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Shopall_Pro_Customize_Horizontal_Line( $wp_customize, 'shopall_pro_theme_options[service_hr_'. $i .']',
        array(
            'section'           => 'shopall_pro_service_section',
            'active_callback'   => 'shopall_pro_is_service_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'shopall_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'shopall_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Shopall_Pro_Dropdown_Taxonomies_Control( $wp_customize,'shopall_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'shopall-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'shopall-pro' ),
	'section'           => 'shopall_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'shopall_pro_is_service_section_content_category_enable'
) ) );