<?php
/**
 * Footer options
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */

// Footer Section
$wp_customize->add_section( 'shopall_pro_section_footer',
	array(
		'title'      			=> esc_html__( 'Footer Options', 'shopall-pro' ),
		'priority'   			=> 900,
		'panel'      			=> 'shopall_pro_theme_options_panel',
	)
);

// footer text
$wp_customize->add_setting( 'shopall_pro_theme_options[copyright_text]',
	array(
		'default'       		=> $options['copyright_text'],
		'sanitize_callback'		=> 'shopall_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'shopall_pro_theme_options[copyright_text]',
    array(
		'label'      			=> esc_html__( 'Copyright Text', 'shopall-pro' ),
		'section'    			=> 'shopall_pro_section_footer',
		'type'		 			=> 'textarea',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[copyright_text]', array(
		'selector'            => '.site-info .wrapper span',
		'settings'            => 'shopall_pro_theme_options[copyright_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'shopall_pro_copyright_text_partial',
    ) );
}

// scroll top visible
$wp_customize->add_setting( 'shopall_pro_theme_options[scroll_top_visible]',
	array(
		'default'       		=> $options['scroll_top_visible'],
		'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[scroll_top_visible]',
    array(
		'label'      			=> esc_html__( 'Display Scroll Top Button', 'shopall-pro' ),
		'section'    			=> 'shopall_pro_section_footer',
		'on_off_label' 		=> shopall_pro_switch_options(),
    )
) );

$wp_customize->add_setting( 'shopall_pro_theme_options[footer_social_enable]', array(
	'default'			=> 	$options['footer_social_enable'],
	'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[footer_social_enable]', array(
	'label'             => esc_html__( 'Social Menu Enable', 'shopall-pro' ),
	'section'           => 'shopall_pro_section_footer',
	'on_off_label' 		=> shopall_pro_switch_options(),
) ) );

// scroll top visible
$wp_customize->add_setting( 'shopall_pro_theme_options[footer_banner_enable]',
	array(
		'default'       		=> $options['footer_banner_enable'],
		'sanitize_callback' => 'shopall_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Shopall_Pro_Switch_Control( $wp_customize, 'shopall_pro_theme_options[footer_banner_enable]',
    array(
		'label'      			=> esc_html__( 'Footer Banner', 'shopall-pro' ),
		'section'    			=> 'shopall_pro_section_footer',
		'on_off_label' 		=> shopall_pro_switch_options(),
    )
) );

$wp_customize->add_setting( 'shopall_pro_theme_options[footer_logo]', array(
	'sanitize_callback' => 'shopall_pro_sanitize_image',
	'default'       		=> '',

) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'shopall_pro_theme_options[footer_logo]',
		array(
		'label'       		=> esc_html__( 'Footer Logo', 'shopall-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'shopall-pro' ), 189, 56 ),
		'section'     		=> 'shopall_pro_section_footer',
) ) );

$wp_customize->add_setting( 'shopall_pro_theme_options[footer_banner]', array(
	'sanitize_callback' => 'shopall_pro_sanitize_image',
	'default'       		=> '',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'shopall_pro_theme_options[footer_banner]',
		array(
		'label'       		=> esc_html__( 'Footer Banner', 'shopall-pro' ),
		'section'     		=> 'shopall_pro_section_footer',
) ) );

$wp_customize->add_setting( 'shopall_pro_theme_options[footer_banner_title]',
	array(
		'default'       		=> $options['footer_banner_title'],
		'sanitize_callback'		=> 'shopall_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'shopall_pro_theme_options[footer_banner_title]',
    array(
		'label'      			=> esc_html__( 'Footer Banner Title', 'shopall-pro' ),
		'section'    			=> 'shopall_pro_section_footer',
		'type'		 			=> 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[footer_banner_title]', array(
		'selector'            => '.mid-footer .entry-header h2',
		'settings'            => 'shopall_pro_theme_options[footer_banner_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'shopall_pro_footer_banner_title_partial',
    ) );
}

$wp_customize->add_setting( 'shopall_pro_theme_options[footer_banner_sub_title]',
	array(
		'default'       		=> $options['footer_banner_sub_title'],
		'sanitize_callback'		=> 'shopall_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'shopall_pro_theme_options[footer_banner_sub_title]',
    array(
		'label'      			=> esc_html__( 'Footer Banner Sub Title', 'shopall-pro' ),
		'section'    			=> 'shopall_pro_section_footer',
		'type'		 			=> 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'shopall_pro_theme_options[footer_banner_sub_title]', array(
		'selector'            => '.mid-footer .entry-header p',
		'settings'            => 'shopall_pro_theme_options[footer_banner_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'shopall_pro_footer_banner_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'shopall_pro_theme_options[footer_app_logo]', array(
	'sanitize_callback' => 'shopall_pro_sanitize_image',
	'default'       	=> $options['footer_app_logo'],

) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'shopall_pro_theme_options[footer_app_logo]',
		array(
		'label'       		=> esc_html__( 'App Store Logo', 'shopall-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'shopall-pro' ), 195, 67 ),
		'section'     		=> 'shopall_pro_section_footer',
) ) );

$wp_customize->add_setting( 'shopall_pro_theme_options[app_store_logo_url]',
	array(
		'sanitize_callback'		=> 'esc_url_raw',
	)
);
$wp_customize->add_control( 'shopall_pro_theme_options[app_store_logo_url]',
    array(
		'label'      			=> esc_html__( 'App Store Logo Url', 'shopall-pro' ),
		'section'    			=> 'shopall_pro_section_footer',
		'type'		 			=> 'url',
    )
);

$wp_customize->add_setting( 'shopall_pro_theme_options[footer_play_logo]', array(
	'sanitize_callback' => 'shopall_pro_sanitize_image',
	'default'       	=> $options['footer_play_logo'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'shopall_pro_theme_options[footer_play_logo]',
		array(
		'label'       		=> esc_html__( 'Google Play Store Logo', 'shopall-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'shopall-pro' ), 195, 67 ),
		'section'     		=> 'shopall_pro_section_footer',
) ) );

$wp_customize->add_setting( 'shopall_pro_theme_options[google_store_logo_url]',
	array(
		'sanitize_callback'		=> 'esc_url_raw',
	)
);
$wp_customize->add_control( 'shopall_pro_theme_options[google_store_logo_url]',
    array(
		'label'      			=> esc_html__( 'Play Store Logo Url', 'shopall-pro' ),
		'section'    			=> 'shopall_pro_section_footer',
		'type'		 			=> 'url',
    )
);
