<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */
if ( ! function_exists( 'shopall_pro_add_latest_product_section' ) ) :
    /**
    * Add about section
    *
    *@since Shopall Pro 1.0.0
    */
    function shopall_pro_add_latest_product_section() {
    	$options = shopall_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $latest_product_enable = apply_filters( 'shopall_pro_section_status', true, 'latest_product_section_enable' );

        if ( true !== $latest_product_enable ) {
            return false;
        }
       
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render about section now.
        shopall_pro_render_latest_product_section( );
    }
endif;


if ( ! function_exists( 'shopall_pro_render_latest_product_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Shopall Pro 1.0.0
   *
   */
   function shopall_pro_render_latest_product_section( ) {
        $options = shopall_pro_get_theme_options()

        ?>

           <div id="latest-products" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="grid clear col-2">
                        <?php for ($i=1; $i <=4 ; $i++) { 
                            $image = $options['latest_product_banner_image_'.$i] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $options['latest_product_banner_image_'.$i] ;
                        ?>
                            <?php if ( !empty( $options['latest_product_banner_image_'.$i]) ): ?>
                                <article class="grid-item">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($image); ?>');">
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><?php echo esc_html( $options['latest_product_banner_label_'.$i] ) ; ?></h2>
                                        </header>
                                        <?php if ( $options['latest_product_category_'.$i] !== '' ) : ?>
                                           <span class="cat-links">
                                                <ul class="post-categories">
                                                    <?php 
                                                    foreach ( $options['latest_product_category_'.$i] as $product_category_id ): 
                                                        $cat_link = get_term_link( $product_category_id, 'product_cat' );
                                                        if ( $options['home_layout'] == 'fourth-design'  
                                                        || !class_exists('WooCommerce') ) {
                                                            $cat_link = get_category_link( $product_category_id );
                                                        }
                                                        ?>
                                                        <li>
                                                            <a href="<?php echo esc_url( $cat_link ) ?>"> 
                                                                <?php 
                                                                    if ( $options['home_layout'] == 'fourth-design' || !class_exists('WooCommerce')) {
                                                                        echo esc_html( get_cat_name( $product_category_id ) );
                                                                    }else{
                                                                        echo esc_html( get_term_by( 'id', $product_category_id, 'product_cat' )->name ); 
                                                                    }
                                                                   
                                                                ?>
                                                                
                                                            </a>
                                                        </li>
                                                    <?php endforeach ; ?>
                                                </ul>
                                            </span><!-- .cat-links -->
                                        <?php endif ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-image -->
                            </article>
                            <?php endif ?>
                           
                        <?php } ?>
                        
                    </div><!-- .grid --> 
                </div><!-- .wrapper -->
            </div><!-- #latest-products -->

        <?php 
    }
endif;