<?php
/**
 * popular product section
 *
 * This is the template for the content of popular product section
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */
if ( ! function_exists( 'shopall_pro_add_popular_product_section' ) ) :
    /**
    * Add popular_product section
    *
    *@since Shopall Pro 1.0.0
    */
    function shopall_pro_add_popular_product_section() {
        $options = shopall_pro_get_theme_options();
        // Check if popular_product is enabled on frontpage
        $popular_product_enable = apply_filters( 'shopall_pro_section_status', true, 'popular_product_section_enable' );

        if ( true !== $popular_product_enable ) {
            return false;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render popular_product section now.
        shopall_pro_render_popular_product_section();
    }
endif;



if ( ! function_exists( 'shopall_pro_render_popular_product_section' ) ) :
  /**
   * Start popular_product section
   *
   * @return string popular_product content
   * @since Shopall Pro 1.0.0
   *
   */
   function shopall_pro_render_popular_product_section( ) {
        $options = shopall_pro_get_theme_options();
     ?>
       <div id="popular-products" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title">
                            <?php echo esc_html($options['popular_product_title']); ?>
                        </h2>
                        <p class="subtitle">
                            <?php echo esc_html($options['popular_product_sub_title']); ?>
                        </p>
                    </div><!-- .section-header -->
                    <?php if ( $options['popular_product_tag'] ): ?>
                        <div class="section-content">
                            <div class="product-filtering">
                                <ul class="product-nav">
                                     <li class="active">
                                            <a href="#" data-slug="all-product">
                                                <?php esc_html_e( 'ALL PRODUCT', 'shopall-pro' ) ; ?>
                                            </a>
                                        </li>
                                    <?php 
                                    foreach ( $options['popular_product_tag'] as $tag ): ?>
                                        <li>
                                            <a href="#" data-slug="<?php echo esc_attr( str_replace ( ' ', '-', get_term_by( 'id', $tag, 'product_tag' )->name ) ) ; ?>"><?php echo esc_html( strtoupper(get_term_by( 'id', $tag, 'product_tag' )->name) ); ?>
                                                
                                            </a>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            </div><!-- .product-filtering -->

                            <ul class="products columns-4 product-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 4, "infinite": false, "speed": 1500, "dots": true, "arrows": true, "autoplay": false, "draggable": true, "fade": false }'>

                                <?php 
                                    foreach ( $options['popular_product_tag'] as $tag ):
                                         $args = array(
                                            'post_type'         => 'product',
                                            'tax_query'         => array(
                                                array(
                                                    'taxonomy'  => 'product_tag',
                                                    'field'     => 'id',
                                                    'terms'     => $tag
                                                )
                                            ) );
                                        $query = new WP_Query( $args );
                                        if ( $query->have_posts() ) : 
                                            while ( $query->have_posts() ) : $query->the_post();
                                            $image = get_the_post_thumbnail_url() == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : get_the_post_thumbnail_url() ;
                                        ?>
                                            <li class="product all-product <?php echo esc_attr( str_replace ( ' ', '-', get_term_by( 'id', $tag, 'product_tag' )->name ) ) ; ?>">
                                                <a href="<?php the_permalink(); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                                    <?php 
                                                        $product = new WC_Product( get_the_id() );
                                                        if ( $product->get_sale_price() ): 
                                                    ?>
                                                            <span class="onsale">
                                                                <?php esc_html_e('Sale!', 'shopall-pro'); ?>
                                                            </span>
                                                    <?php endif ?>
                                                    
                                                    <img width="330" height="400" src="<?php echo esc_url($image); ?>">
                                                    <div class="product_meta">
                                                        <?php 
                                                            $terms = get_the_terms ( get_the_id(), 'product_cat' );
                                                            foreach ( $terms as $term ) { ?>
                                                                <span class="posted_in">
                                                                    <a href="<?php echo esc_url( get_term_link( $term->term_id, 'product_cat' ) ) ?>"><?php echo esc_html( $term->name) ; ?></a>
                                                                </span><!-- .posted_in -->
                                                               
                                                            <?php }
                                                        ?>
                                                    </div><!-- .product-meta -->
                                                    <h2 class="woocommerce-loop-product__title"><?php the_title( ); ?></h2>
                                                    <span class="price">
                                                        <?php 
                                                            $product = new WC_Product( get_the_id() );
                                                            echo $product->get_price_html();
                                                        ?>
                                                       
                                                    </span>
                                                </a>
                                                
                                                <a href="<?php echo do_shortcode( '[add_to_cart_url id="' . absint( $content['id'] ) . '"]' ); ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart">
                                                    <?php esc_html_e('Add to cart', 'shopall-pro') ?>
                                                </a>
                                            </li>
                                        <?php                                           
                                            endwhile;
                                        endif;
                                        wp_reset_postdata();
                                    endforeach;
                                   
                                 ?>                            
                            </ul><!-- .product-slider -->
                        </div><!-- .section-content -->
                    <?php endif ?>
                    
                </div><!-- .wrapper -->
            </div><!-- #popular-products -->
        
    <?php }
endif;