<?php
/**
 * product_collection section
 *
 * This is the template for the content of product_collection section
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */
if ( ! function_exists( 'shopall_pro_add_product_collection_section' ) ) :
    /**
    * Add product_collection section
    *
    *@since Shopall Pro 1.0.0
    */
    function shopall_pro_add_product_collection_section() {
    	$options = shopall_pro_get_theme_options();
        // Check if product_collection is enabled on frontpage
        $product_collection_enable = apply_filters( 'shopall_pro_section_status', true, 'product_collection_section_enable' );

        if ( true !== $product_collection_enable ) {
            return false;
        }
        // Get product_collection section details
        $section_details = array();
        $section_details = apply_filters( 'shopall_pro_filter_product_collection_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render product_collection section now.
        shopall_pro_render_product_collection_section( $section_details );
    }
endif;

if ( ! function_exists( 'shopall_pro_get_product_collection_section_details' ) ) :
    /**
    * product_collection section details.
    *
    * @since Shopall Pro 1.0.0
    * @param array $input product_collection section details.
    */
    function shopall_pro_get_product_collection_section_details( $input ) {
        $options = shopall_pro_get_theme_options();

        // Content type.
        $product_collection_content_type  = $options['product_collection_content_type'];
        $product_collection_count = ! empty( $options['product_collection_count'] ) ? $options['product_collection_count'] : 3;
        
        $content = array();
        switch ( $product_collection_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $product_collection_count; $i++ ) {
                    if ( ! empty( $options['product_collection_content_page_' . $i] ) )
                        $page_ids[] = $options['product_collection_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $product_collection_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $product_collection_count; $i++ ) {
                    if ( ! empty( $options['product_collection_content_post_' . $i] ) )
                        $post_ids[] = $options['product_collection_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $product_collection_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['product_collection_content_category'] ) ? $options['product_collection_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $product_collection_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = shopall_pro_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';
                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product_collection section content details.
add_filter( 'shopall_pro_filter_product_collection_section_details', 'shopall_pro_get_product_collection_section_details' );


if ( ! function_exists( 'shopall_pro_render_product_collection_section' ) ) :
  /**
   * Start product_collection section
   *
   * @return string product_collection content
   * @since Shopall Pro 1.0.0
   *
   */
   function shopall_pro_render_product_collection_section( $content_details = array() ) {
        $options = shopall_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="products-collection" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title">
                            <?php echo esc_html( $options['product_collection_title'] ) ; ?>
                        </h2>
                        <p class="subtitle">
                            <?php echo esc_html( $options['product_collection_sub_title'] ) ; ?>
                        </p>
                    </div><!-- .section-header -->

                    <div class="section-content grid col-2" style="position: relative; height: 1160px;">
                        <?php 
                            $i = 1 ; 
                            $j = 1 ;
                            foreach ($content_details as $content): 
                            if ( $i == 1 ) {
                                $left = 0;
                                $top = 0;
                            }elseif( $i == 2 ){
                                $left = 690.5;
                                $top = 0;
                            }elseif( $i == 3 ){
                                $left = 0;
                                $top = 500;
                            }elseif( $i == 4 ){
                                $left = 690.5;
                                $top = 680;
                            }
                            
                            $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                            $background = shopall_pro_image_brightness($image);
                            $color = $background == '#000' ? '#fff' : '#000' ;
                        ?>
                            <article class="grid-item" style="position: absolute; left: <?php echo $left; ?>px; top: <?php echo $top; ?>px;">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ) ; ?>');">
                                    <div class="entry-container">
                                        <span class="cat-links">
                                            <ul class="post-categories">
                                                <?php foreach ( get_the_category( $content['id'] ) as $category ): ?>
                                                    <li>
                                                        <a href="<?php echo esc_url( get_category_link($category->term_id) ) ; ?>" rel="category" style="color:<?php echo $options['home_layout'] == 'fifth-design' ? '' : $background ?>">
                                                            <?php echo esc_html( $category->name ); ?>
                                                        </a>
                                                    </li>
                                                <?php endforeach ?>                                                
                                            </ul>
                                        </span>

                                        <header class="entry-header">
                                            <h2 class="entry-title">
                                                <a href="<?php echo esc_url( $content['url'] ) ; ?>" style="color:<?php echo $options['home_layout'] == 'fifth-design' ? '' : $background ?>">
                                                    <?php echo esc_html( $content['title'] ) ; ?>
                                                </a>
                                            </h2>
                                        </header>

                                        <?php if ( $options['home_layout'] !== 'fourth-design' ): ?>
                                            <?php if ( !empty( $options['product_collection_btn_url_'.$j] ) && !empty( $options['product_collection_btn_title_'.$j] ) ): ?>
                                                <div class="read-more">

                                                    <a href="<?php echo esc_url( $options['product_collection_btn_url_'.$j] ) ; ?>" class="btn" style="color:<?php echo $color ?>; background:<?php echo $background ; ?>; border-color:<?php echo $background ; ?>" onMouseOver="this.style.background='#fa311f';this.style.border='<?php echo $color ; ?>';this.style.color='#fff'" onMouseOut="this.style.background='<?php echo $background ; ?>';this.style.border='<?php echo $background ; ?>';this.style.color='<?php echo $color ; ?>'">
                                                        <?php echo esc_html( $options['product_collection_btn_title_'.$j] ) ; ?>
                                                    </a>
                                                </div><!-- .read-more -->
                                            <?php endif ?>
                                        <?php endif ?>

                                        <?php if ( $options['home_layout'] == 'fourth-design' ): ?>
                                            <?php if ( !empty( $options['product_collection_btn_title'] ) ): ?>
                                                <div class="read-more">
                                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="btn" style="color:<?php echo $color ?>; background:<?php echo $background ; ?>; border-color:<?php echo $background ; ?>" onMouseOver="this.style.background='#fa311f';this.style.border='<?php echo $color ; ?>';this.style.color='#fff'" onMouseOut="this.style.background='<?php echo $background ; ?>';this.style.border='<?php echo $background ; ?>';this.style.color='<?php echo $color ; ?>'">
                                                        <?php echo esc_html( $options['product_collection_btn_title'] ) ; ?>
                                                    </a>
                                                </div><!-- .read-more -->
                                            <?php endif ?>
                                        <?php endif ?>
                                        
                                        
                                        <?php if ( $options['home_layout'] == 'fifth-design' ): ?>
                                            <ul class="social-icons">
                                                <?php 
                                                    $product_collection_socials = ! empty( $options['product_collection_social_' . $i ] ) ? explode( '|', $options['product_collection_social_' . $i ] ) : array(); 

                                                    foreach ( $product_collection_socials as $product_collection_social ) : ?>
                                                        <li>
                                                            <a href="<?php echo esc_url( $product_collection_social ); ?>"><?php echo shopall_pro_return_social_icon( $product_collection_social ); ?></a>
                                                        </li>
                                                    <?php endforeach; 
                                                ?>
                                            </ul>
                                        <?php endif ?>
                                        
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-image -->
                            </article>
                        <?php 
                        $i = $i == 4 ? 0 : $i ;
                        $i++;  
                        $j++;
                        endforeach ; 
                        ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>
        
    <?php }
endif;